@@ -1,4 +1,4 @@
-# Copyright 2010-2023 The pygit2 contributors
+# Copyright 2010-2025 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -34,13 +34,13 @@ from pathlib import Path
 #
 # The version number of pygit2
 #
-__version__ = '1.12.1'
+__version__ = '1.19.1'
 
 
 #
-# Utility functions to get the paths required for bulding extensions
+# Utility functions to get the paths required for building extensions
 #
-def _get_libgit2_path():
+def _get_libgit2_path() -> Path:
     # LIBGIT2 environment variable takes precedence
     libgit2_path = os.getenv('LIBGIT2')
     if libgit2_path is not None:
@@ -52,7 +52,7 @@ def _get_libgit2_path():
     return Path('/usr/local')
 
 
-def get_libgit2_paths():
+def get_libgit2_paths() -> tuple[Path, dict[str, list[str]]]:
     # Base path
     path = _get_libgit2_path()
 
@@ -61,7 +61,7 @@ def get_libgit2_paths():
     if libgit2_lib is None:
         library_dirs = [path / 'lib', path / 'lib64']
     else:
-        library_dirs = [libgit2_lib]
+        library_dirs = [Path(libgit2_lib)]
 
     include_dirs = [path / 'include']
     return (
@@ -70,5 +70,5 @@ def get_libgit2_paths():
             'libraries': ['git2'],
             'include_dirs': [str(x) for x in include_dirs],
             'library_dirs': [str(x) for x in library_dirs],
-        }
+        },
     )
